@@ -30,7 +30,7 @@
  DAMAGE. 
  =========================================================================*/
 
-/** @file
+/*
  *	command history
  *
  *	cscope - interactive C symbol or text cross-reference
@@ -40,8 +40,6 @@
 
 #include "alloc.h"
 
-static char const rcsid[] = "$Id: history.c,v 1.2 2012/10/13 07:02:06 shigio Exp $";
-
 static	struct cmd *tail, *current;
 
 /**
